==> types_aiobotocore_migration_hub_refactor_spaces-2.3.1-py3-none-any.whl: types_aiobotocore_migration_hub_refactor_spaces/literals.py <==
"""
Type annotations for migration-hub-refactor-spaces service literal definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_migration_hub_refactor_spaces/literals/)

Usage::

    ```python
    from types_aiobotocore_migration_hub_refactor_spaces.literals import ApiGatewayEndpointTypeType

    data: ApiGatewayEndpointTypeType = "PRIVATE"
    ```
"""
import sys

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "ApiGatewayEndpointTypeType",
    "ApplicationStateType",
    "EnvironmentStateType",
    "ErrorCodeType",
    "ErrorResourceTypeType",
    "HttpMethodType",
    "ListApplicationsPaginatorName",
    "ListEnvironmentVpcsPaginatorName",
    "ListEnvironmentsPaginatorName",
    "ListRoutesPaginatorName",
    "ListServicesPaginatorName",
    "NetworkFabricTypeType",
    "ProxyTypeType",
    "RouteActivationStateType",
    "RouteStateType",
    "RouteTypeType",
    "ServiceEndpointTypeType",
    "ServiceStateType",
    "MigrationHubRefactorSpacesServiceName",
    "ServiceName",
    "ResourceServiceName",
    "PaginatorName",
)


ApiGatewayEndpointTypeType = Literal["PRIVATE", "REGIONAL"]
ApplicationStateType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "UPDATING"]
EnvironmentStateType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED"]
ErrorCodeType = Literal[
    "INVALID_RESOURCE_STATE",
    "NOT_AUTHORIZED",
    "REQUEST_LIMIT_EXCEEDED",
    "RESOURCE_CREATION_FAILURE",
    "RESOURCE_DELETION_FAILURE",
    "RESOURCE_IN_USE",
    "RESOURCE_LIMIT_EXCEEDED",
    "RESOURCE_NOT_FOUND",
    "RESOURCE_RETRIEVAL_FAILURE",
    "RESOURCE_UPDATE_FAILURE",
    "SERVICE_ENDPOINT_HEALTH_CHECK_FAILURE",
    "STATE_TRANSITION_FAILURE",
]
ErrorResourceTypeType = Literal[
    "API_GATEWAY",
    "APPLICATION",
    "ENVIRONMENT",
    "IAM_ROLE",
    "LAMBDA",
    "LOAD_BALANCER_LISTENER",
    "NLB",
    "RESOURCE_SHARE",
    "ROUTE",
    "ROUTE_TABLE",
    "SECURITY_GROUP",
    "SERVICE",
    "SUBNET",
    "TARGET_GROUP",
    "TRANSIT_GATEWAY",
    "TRANSIT_GATEWAY_ATTACHMENT",
    "VPC",
    "VPC_ENDPOINT_SERVICE_CONFIGURATION",
    "VPC_LINK",
]
HttpMethodType = Literal["DELETE", "GET", "HEAD", "OPTIONS", "PATCH", "POST", "PUT"]
ListApplicationsPaginatorName = Literal["list_applications"]
ListEnvironmentVpcsPaginatorName = Literal["list_environment_vpcs"]
ListEnvironmentsPaginatorName = Literal["list_environments"]
ListRoutesPaginatorName = Literal["list_routes"]
ListServicesPaginatorName = Literal["list_services"]
NetworkFabricTypeType = Literal["TRANSIT_GATEWAY"]
ProxyTypeType = Literal["API_GATEWAY"]
RouteActivationStateType = Literal["ACTIVE"]
RouteStateType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "INACTIVE", "UPDATING"]
RouteTypeType = Literal["DEFAULT", "URI_PATH"]
ServiceEndpointTypeType = Literal["LAMBDA", "URL"]
ServiceStateType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED"]
MigrationHubRefactorSpacesServiceName = Literal["migration-hub-refactor-spaces"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "alexaforbusiness",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "backup",
    "backup-gateway",
    "batch",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecommit",
    "codedeploy",
    "codeguru-reviewer",
    "codeguruprofiler",
    "codepipeline",
    "codestar",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectparticipant",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "dax",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "drs",
    "ds",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "elastic-inference",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "fsx",
    "gamelift",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "honeycode",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector2",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot1click-devices",
    "iot1click-projects",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "kafka",
    "kafkaconnect",
    "kendra",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "machinelearning",
    "macie",
    "macie2",
    "managedblockchain",
    "marketplace-catalog",
    "marketplace-entitlement",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhubstrategy",
    "mobile",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "network-firewall",
    "networkmanager",
    "nimble",
    "opensearch",
    "opsworks",
    "opsworkscm",
    "organizations",
    "outposts",
    "panorama",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "polly",
    "pricing",
    "proton",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "rekognition",
    "resiliencehub",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-runtime",
    "savingsplans",
    "schemas",
    "sdb",
    "secretsmanager",
    "securityhub",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-incidents",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "support",
    "swf",
    "synthetics",
    "textract",
    "timestream-query",
    "timestream-write",
    "transcribe",
    "transfer",
    "translate",
    "voice-id",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "worklink",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]
PaginatorName = Literal[
    "list_applications",
    "list_environment_vpcs",
    "list_environments",
    "list_routes",
    "list_services",
]

==> types_aiobotocore_migration_hub_refactor_spaces-2.4.0-py3-none-any.whl: types_aiobotocore_migration_hub_refactor_spaces/literals.py <==
"""
Type annotations for migration-hub-refactor-spaces service literal definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_migration_hub_refactor_spaces/literals/)

Usage::

    ```python
    from types_aiobotocore_migration_hub_refactor_spaces.literals import ApiGatewayEndpointTypeType

    data: ApiGatewayEndpointTypeType = "PRIVATE"
    ```
"""
import sys

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "ApiGatewayEndpointTypeType",
    "ApplicationStateType",
    "EnvironmentStateType",
    "ErrorCodeType",
    "ErrorResourceTypeType",
    "HttpMethodType",
    "ListApplicationsPaginatorName",
    "ListEnvironmentVpcsPaginatorName",
    "ListEnvironmentsPaginatorName",
    "ListRoutesPaginatorName",
    "ListServicesPaginatorName",
    "NetworkFabricTypeType",
    "ProxyTypeType",
    "RouteActivationStateType",
    "RouteStateType",
    "RouteTypeType",
    "ServiceEndpointTypeType",
    "ServiceStateType",
    "MigrationHubRefactorSpacesServiceName",
    "ServiceName",
    "ResourceServiceName",
    "PaginatorName",
)


ApiGatewayEndpointTypeType = Literal["PRIVATE", "REGIONAL"]
ApplicationStateType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "UPDATING"]
EnvironmentStateType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED"]
ErrorCodeType = Literal[
    "INVALID_RESOURCE_STATE",
    "NOT_AUTHORIZED",
    "REQUEST_LIMIT_EXCEEDED",
    "RESOURCE_CREATION_FAILURE",
    "RESOURCE_DELETION_FAILURE",
    "RESOURCE_IN_USE",
    "RESOURCE_LIMIT_EXCEEDED",
    "RESOURCE_NOT_FOUND",
    "RESOURCE_RETRIEVAL_FAILURE",
    "RESOURCE_UPDATE_FAILURE",
    "SERVICE_ENDPOINT_HEALTH_CHECK_FAILURE",
    "STATE_TRANSITION_FAILURE",
]
ErrorResourceTypeType = Literal[
    "API_GATEWAY",
    "APPLICATION",
    "ENVIRONMENT",
    "IAM_ROLE",
    "LAMBDA",
    "LOAD_BALANCER_LISTENER",
    "NLB",
    "RESOURCE_SHARE",
    "ROUTE",
    "ROUTE_TABLE",
    "SECURITY_GROUP",
    "SERVICE",
    "SUBNET",
    "TARGET_GROUP",
    "TRANSIT_GATEWAY",
    "TRANSIT_GATEWAY_ATTACHMENT",
    "VPC",
    "VPC_ENDPOINT_SERVICE_CONFIGURATION",
    "VPC_LINK",
]
HttpMethodType = Literal["DELETE", "GET", "HEAD", "OPTIONS", "PATCH", "POST", "PUT"]
ListApplicationsPaginatorName = Literal["list_applications"]
ListEnvironmentVpcsPaginatorName = Literal["list_environment_vpcs"]
ListEnvironmentsPaginatorName = Literal["list_environments"]
ListRoutesPaginatorName = Literal["list_routes"]
ListServicesPaginatorName = Literal["list_services"]
NetworkFabricTypeType = Literal["TRANSIT_GATEWAY"]
ProxyTypeType = Literal["API_GATEWAY"]
RouteActivationStateType = Literal["ACTIVE", "INACTIVE"]
RouteStateType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "INACTIVE", "UPDATING"]
RouteTypeType = Literal["DEFAULT", "URI_PATH"]
ServiceEndpointTypeType = Literal["LAMBDA", "URL"]
ServiceStateType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED"]
MigrationHubRefactorSpacesServiceName = Literal["migration-hub-refactor-spaces"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "alexaforbusiness",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "backup",
    "backup-gateway",
    "backupstorage",
    "batch",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-media-pipelines",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecommit",
    "codedeploy",
    "codeguru-reviewer",
    "codeguruprofiler",
    "codepipeline",
    "codestar",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectcampaigns",
    "connectparticipant",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "dax",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "drs",
    "ds",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "elastic-inference",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "emr-serverless",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "fsx",
    "gamelift",
    "gamesparks",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "honeycode",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector2",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot1click-devices",
    "iot1click-projects",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "ivschat",
    "kafka",
    "kafkaconnect",
    "kendra",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "license-manager-user-subscriptions",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "m2",
    "machinelearning",
    "macie",
    "macie2",
    "managedblockchain",
    "marketplace-catalog",
    "marketplace-entitlement",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhubstrategy",
    "mobile",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "network-firewall",
    "networkmanager",
    "nimble",
    "opensearch",
    "opsworks",
    "opsworkscm",
    "organizations",
    "outposts",
    "panorama",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "pinpoint-sms-voice-v2",
    "polly",
    "pricing",
    "privatenetworks",
    "proton",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "redshift-serverless",
    "rekognition",
    "resiliencehub",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "rolesanywhere",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-runtime",
    "savingsplans",
    "schemas",
    "sdb",
    "secretsmanager",
    "securityhub",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-incidents",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "support",
    "support-app",
    "swf",
    "synthetics",
    "textract",
    "timestream-query",
    "timestream-write",
    "transcribe",
    "transfer",
    "translate",
    "voice-id",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "worklink",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]
PaginatorName = Literal[
    "list_applications",
    "list_environment_vpcs",
    "list_environments",
    "list_routes",
    "list_services",
]
